<?php 
/*
	CUSTOM WIDGETS for 'Tao of WordPress' theme

	NOTES

	- Do not modify this file directly, use a child theme to add new widgets

	- This file contains two custom WordPress widgets (each requiring PHP 5.3 or better):

		 Clean Markup Widget         @ https://wp-tao.com/540
		 Post Format Archives Widget @ https://wp-tao.com/541

	- Learn more:
		@ https://codex.wordpress.org/Widgets_API
		@ http://www.billerickson.net/creating-a-wordpress-widget/

*/


// Clean Markup Widget @ https://wp-tao.com/540
if (!class_exists('Clean_Markup_Widget')) {
	class Clean_Markup_Widget extends WP_Widget {
		function __construct() {
			parent::__construct('clean_markup_widget', 'Clean markup widget', array('description'=>'Simple widget for well-formatted markup &amp; text'));
		}
		function widget($args, $instance) {
			extract($args);
			$markup = $instance['markup'];
			//echo $before_widget;
			if ($markup) echo $markup;
			//echo $after_widget;
		}
		function update($new_instance, $old_instance) {
			$instance = $old_instance;
			$instance['markup'] = $new_instance['markup'];
			return $instance;
		}
		function form($instance) {
			if ($instance) $markup = esc_attr($instance['markup']);
			else $markup = __('&lt;p&gt;Clean, well-formatted markup.&lt;/p&gt;', 'tao-of-wordpress'); ?>
			<p>
				<label for="<?php echo $this->get_field_id('markup'); ?>"><?php _e('Markup/text', 'tao-of-wordpress'); ?></label><br />
				<textarea class="widefat" id="<?php echo $this->get_field_id('markup'); ?>" name="<?php echo $this->get_field_name('markup'); ?>" type="text" rows="16" cols="20" value="<?php echo $markup; ?>"><?php echo $markup; ?></textarea>
			</p>
	<?php }
	}
}
add_action('widgets_init', create_function('', 'register_widget("clean_markup_widget");'));


// Post Format Archives Widget @ https://wp-tao.com/541
if (!class_exists('Post_Format_Archives_Widget')) {
	class Post_Format_Archives_Widget extends WP_Widget {
		function __construct() {
			parent::__construct('post_format_archives_widget', 'Post Format Archives', array('description'=>'Displays a list of links to post-format archives'));
		}
		function widget($args, $instance) {
			extract($args, EXTR_SKIP);
	
			$title  = empty($instance['title']) ? ' ' : apply_filters('widget_title', $instance['title']);
			$aside  = empty($instance['aside']) ? ' ' : apply_filters('widget_aside', $instance['aside']);
			$image  = empty($instance['image']) ? ' ' : apply_filters('widget_image', $instance['image']);
			$link   = empty($instance['link']) ? ' ' : apply_filters('widget_link', $instance['link']);
			$quote  = empty($instance['quote']) ? ' ' : apply_filters('widget_quote', $instance['quote']);
			$status = empty($instance['status']) ? ' ' : apply_filters('widget_status', $instance['status']);
	
			echo $before_widget;
			if (!empty($title)) { echo $before_title . $title . $after_title; };
	
			// @ https://codex.wordpress.org/Function_Reference/get_post_format_link
			echo '<ul id="custom-post-format-widget">';
			echo '	<li><a href="' . get_post_format_link('aside') . '">' . $aside . '</a></li>';
			echo '	<li><a href="' . get_post_format_link('image') . '">' . $image . '</a></li>';
			echo '	<li><a href="' . get_post_format_link('link') . '">' . $link . '</a></li>';
			echo '	<li><a href="' . get_post_format_link('quote') . '">' . $quote . '</a></li>';
			echo '	<li><a href="' . get_post_format_link('status') . '">' . $status . '</a></li>';
			echo '</ul>';
	
			echo $after_widget;
		}
		function update($new_instance, $old_instance) {
			$instance = $old_instance;
			$instance['title']  = strip_tags($new_instance['title']);
			$instance['aside']  = strip_tags($new_instance['aside']);
			$instance['image']  = strip_tags($new_instance['image']);
			$instance['link']   = strip_tags($new_instance['link']);
			$instance['quote']  = strip_tags($new_instance['quote']);
			$instance['status'] = strip_tags($new_instance['status']);
			return $instance;
		}
		function form($instance) {
			$defaults = array(
				'title' => __('Browse the site', 'tao-of-wordpress'), 
				'aside' => __('View Aside posts', 'tao-of-wordpress'), 
				'image' => __('View Image posts', 'tao-of-wordpress'), 
				'link' => __('View Link posts', 'tao-of-wordpress'), 
				'quote' => __('View Quote posts', 'tao-of-wordpress'), 
				'status' => __('View Status posts', 'tao-of-wordpress'),
			);
			$instance = wp_parse_args((array) $instance, $defaults);
			$title = strip_tags($instance['title']);
			$aside = strip_tags($instance['aside']);
			$image = strip_tags($instance['image']);
			$link = strip_tags($instance['link']);
			$quote = strip_tags($instance['quote']);
			$status = strip_tags($instance['status']); ?>
	
			<p><label for="<?php echo $this->get_field_id('title'); ?>">Title text</label>
				<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
			</p>
			<p><label for="<?php echo $this->get_field_id('aside'); ?>"><?php _e('Link text for Aside archive', 'tao-of-wordpress'); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id('aside'); ?>" name="<?php echo $this->get_field_name('aside'); ?>" type="text" value="<?php echo esc_attr($aside); ?>" />
			</p>
			<p><label for="<?php echo $this->get_field_id('image'); ?>"><?php _e('Link text for Image archive', 'tao-of-wordpress'); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id('image'); ?>" name="<?php echo $this->get_field_name('image'); ?>" type="text" value="<?php echo esc_attr($image); ?>" />
			</p>
			<p><label for="<?php echo $this->get_field_id('link'); ?>"><?php _e('Link text for Link archive', 'tao-of-wordpress'); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id('link'); ?>" name="<?php echo $this->get_field_name('link'); ?>" type="text" value="<?php echo esc_attr($link); ?>" />
			</p>
			<p><label for="<?php echo $this->get_field_id('quote'); ?>"><?php _e('Link text for Quote archive', 'tao-of-wordpress'); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id('quote'); ?>" name="<?php echo $this->get_field_name('quote'); ?>" type="text" value="<?php echo esc_attr($quote); ?>" />
			</p>
			<p><label for="<?php echo $this->get_field_id('status'); ?>"><?php _e('Link text for Status archive', 'tao-of-wordpress'); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id('status'); ?>" name="<?php echo $this->get_field_name('status'); ?>" type="text" value="<?php echo esc_attr($status); ?>" />
			</p>
	<?php }
	}
}
add_action('widgets_init', create_function('', 'register_widget("Post_Format_Archives_Widget");'));

